@@ -19,9 +19,9 @@ class EmulateEfuseController(EmulateEfuseControllerBase):
 
     def __init__(self, efuse_file=None, debug=False):
         self.Blocks = EfuseDefineBlocks
-        self.Fields = EfuseDefineFields()
+        self.Fields = EfuseDefineFields(None)
         self.REGS = EfuseDefineRegisters
-        super(EmulateEfuseController, self).__init__(efuse_file, debug)
+        super().__init__(efuse_file, debug)
         self.write_reg(self.REGS.EFUSE_CMD_REG, 0)
 
     """ esptool method start >>"""
